numpy.random.mtrand.RandomState
===============================

.. currentmodule:: numpy.random.mtrand

.. autoclass:: RandomState

   

   .. HACK
      .. autosummary::
         :toctree:
      
         RandomState.__init__
         RandomState.beta
         RandomState.binomial
         RandomState.bytes
         RandomState.chisquare
         RandomState.dirichlet
         RandomState.exponential
         RandomState.f
         RandomState.gamma
         RandomState.geometric
         RandomState.get_state
         RandomState.gumbel
         RandomState.hypergeometric
         RandomState.laplace
         RandomState.logistic
         RandomState.lognormal
         RandomState.logseries
         RandomState.multinomial
         RandomState.multivariate_normal
         RandomState.negative_binomial
         RandomState.noncentral_chisquare
         RandomState.noncentral_f
         RandomState.normal
         RandomState.pareto
         RandomState.permutation
         RandomState.poisson
         RandomState.power
         RandomState.rand
         RandomState.randint
         RandomState.randn
         RandomState.random_integers
         RandomState.random_sample
         RandomState.rayleigh
         RandomState.seed
         RandomState.set_state
         RandomState.shuffle
         RandomState.standard_cauchy
         RandomState.standard_exponential
         RandomState.standard_gamma
         RandomState.standard_normal
         RandomState.standard_t
         RandomState.tomaxint
         RandomState.triangular
         RandomState.uniform
         RandomState.vonmises
         RandomState.wald
         RandomState.weibull
         RandomState.zipf



   

